# react-native-metaone-wallet-sdk

**Step 1: Setting up SSH for access to your repositories**

After you are accepted to the SDK integration program, you will be provided with SSH keys required to access secure repositories. If you haven’t received them please ask your integration success manager to provide you files.

**Step 2: Installing dependency**

`npm i react-native-metaone-wallet-sdk -s` or `yarn add react-native-metaone-wallet-sdk`

**Step 2: Adding MetaOne Wallet SDK**

### Android

Add the following config to your "local.properties" file inside the Android directory:

```
walletsdk.maven.url=url // given by aag
walletsdk.maven.username=username // given by aag
walletsdk.maven.password=password // given by aag
```

Add the following code to your build.gradle file:

```
url properties.getProperty('walletsdk.maven.url')
credentials {
    username = properties.getProperty('walletsdk.maven.username')
    password = properties.getProperty('walletsdk.maven.password')
}
```

### iOS
#### 1. Add the following code to your Podfile:
```
// Add to top of Podfile
source 'https://cdn.cocoapods.org/'
source 'https://bitbucket.org/cybavo/Specs_512.git'
```

```
target 'YourTarget' do
  use_frameworks! // Add this line
end
```

```
post_install do |installer|
    installer.pods_project.targets.each do |target|
        target.build_configurations.each do |config|
            config.build_settings['IPHONEOS_DEPLOYMENT_TARGET'] = '14.0' // Add this line
            config.build_settings['BUILD_LIBRARY_FOR_DISTRIBUTION'] = 'YES' // Add this line
        end
    end
end
```

#### 2. Run `pod install` in `ios/`


**Step 3: Initializing SDK**

Initialize MetaOne SDK:

```
await initialize({
    sdkEnvironment: sdkConfig.environment, // test, stage, prod
    sdkKey: Platform.OS === "ios" ? sdkConfig.iOSKey : sdkConfig.androidKey,  // given by aag
    sdkConfigUrl: sdkConfig.configUrl, // given by aag
    sdkApiClientReference: sdkConfig.apiClientReference, //  given by aag
    sdkApiKeyPhrase: sdkConfig.apiKeyPhrase, // given by client
    version, // app version
    sdkRealm: sdkConfig.realm, //  given by aag
    mainnet: sdkConfig.mainnet  // specify maninet or testnet
});
```

Check session status:

```await getSessionActivityStatus();```

**Step 4: Creating User Session**

To successfully initialize a user session your back-end integration has to be ready first. Your backend should receive an Authorization token during the initialization request.

Initialize the session by calling: `logInWithSSO(token);`

Your session is initialized. You can now use all other functions that require Authorization

Call `setupUserData();` to initialize user profile data

### Important:

To ensure a good user experience, we recommend you implement:

1. Initialize user session during initial auth
2. Refresh the user session when the session expires.