package com.metaonewalletreactnativesdk

import com.facebook.react.bridge.*
import com.google.gson.Gson
import ventures.aag.metaonesdk.helpers.Helpers.Companion.Languages
import ventures.aag.metaonesdk.managers.MetaOneSDKManager
import ventures.aag.metaonesdk.models.*
import ventures.aag.metaonesdk.models.api.UserApiModel

class MetaoneWalletReactNativeSdkModule(reactContext: ReactApplicationContext) :
  ReactContextBaseJavaModule(reactContext) {
  private var metaOneSDKManager: MetaOneSDKManager = MetaOneSDKManager(reactApplicationContext)
  override fun getName(): String {
    return NAME
  }

  @ReactMethod
  fun initialize(config: ReadableMap, promise: Promise) {
    metaOneSDKManager = MetaOneSDKManager(reactApplicationContext)
    var sdkConfig = Gson().fromJson(config.toString(), SDKConfig::class.java)
    metaOneSDKManager.initialize(
      sdkConfig,
      PromiseCallback(promise),
    )
  }

  @ReactMethod
  fun loginWithSSO(token: String, promise: Promise) {
    metaOneSDKManager.login(
      token,
      reactApplicationContext,
      PromiseCallback(promise),
    )
  }

  @ReactMethod
  fun setupUserData(promise: Promise) {
    metaOneSDKManager.setupUserData(object : M1EnqueueCallback<Pair<UserApiModel.GetProfileResponse?, User.UserState?>>() {
      override fun onSuccess(response: Pair<UserApiModel.GetProfileResponse?, User.UserState?>) {
        var map: WritableMap = WritableNativeMap()
        response.first?.let {
          map = Helper().stringToMap(Gson().toJson(this))
        }
        response.second?.let {
          map.putMap("userState", Helper().stringToMap(Gson().toJson(this)))
        }
        promise.resolve(map)
      }

      override fun onError(errorBody: ErrorResponse) {
        promise.resolve(false)
      }

      override fun onFailure(message: String) {
        promise.resolve(false)
      }
    })
  }

  @ReactMethod
  fun refreshSession(promise: Promise) {
    metaOneSDKManager.refreshSession(PromiseCallback(promise))
  }

  @ReactMethod
  fun openWallet() {
    metaOneSDKManager.openWallet()
  }

  @ReactMethod
  fun getSessionActivityStatus(promise: Promise) {
    var sessionActivityStatus = metaOneSDKManager.getSessionActivityStatus()
    promise.resolve(sessionActivityStatus.toString())
  }

  @ReactMethod
  fun getColorsScheme(promise: Promise) {
    val colorsScheme = metaOneSDKManager.uiManager.getColorsScheme()
    if (colorsScheme != null) {
      promise.resolve(Helper().stringToMap(Gson().toJson(colorsScheme)))
    } else {
      promise.resolve(null)
    }
  }

  @ReactMethod
  fun setColorsScheme(colors: ReadableMap) {
    val colorsScheme = Gson().fromJson(colors.toString(), M1Color.ColorsScheme::class.java)
    metaOneSDKManager.uiManager.setColorsScheme(colorsScheme)
  }

  @ReactMethod
  fun getCurrentLanguage(promise: Promise) {
    val currentLanguage = metaOneSDKManager.uiManager.getCurrentLanguage()
    val webLocale = when (currentLanguage.toString()) {
      Languages.ENGLISH.appLocale -> {
        Languages.ENGLISH.webLocale
      }
      Languages.VIETNAMESE.appLocale -> {
        Languages.VIETNAMESE.webLocale
      }
      Languages.INDONESIAN.appLocale -> {
        Languages.INDONESIAN.webLocale
      }
      Languages.FILIPINO.appLocale -> {
        Languages.FILIPINO.webLocale
      }
      Languages.CHINESE_SIMPLIFIED.appLocale -> {
        Languages.CHINESE_SIMPLIFIED.webLocale
      }
      Languages.CHINESE_TRADITIONAL.appLocale -> {
        Languages.CHINESE_TRADITIONAL.webLocale
      }
      else -> { currentLanguage.toString() }
    }
    promise.resolve(webLocale)
  }

  @ReactMethod
  fun setCurrentLanguage(locale: String) {
    val appLocale = when (locale) {
      Languages.ENGLISH.webLocale -> {
        Languages.ENGLISH.appLocale
      }
      Languages.VIETNAMESE.webLocale -> {
        Languages.VIETNAMESE.appLocale
      }
      Languages.INDONESIAN.webLocale -> {
        Languages.INDONESIAN.appLocale
      }
      Languages.FILIPINO.webLocale -> {
        Languages.FILIPINO.appLocale
      }
      Languages.CHINESE_SIMPLIFIED.webLocale -> {
        Languages.CHINESE_SIMPLIFIED.appLocale
      }
      Languages.CHINESE_TRADITIONAL.webLocale -> {
        Languages.CHINESE_TRADITIONAL.appLocale
      }
      else -> { Languages.ENGLISH.appLocale }
    }
    metaOneSDKManager.uiManager.setCurrentLanguage(appLocale)
  }

  @ReactMethod
  fun getWallets(promise: Promise) {
    metaOneSDKManager.apiManager.getWallets(PromiseCallback(promise))
  }

  @ReactMethod
  fun getCurrencies(promise: Promise) {
    metaOneSDKManager.apiManager.getCurrencies(PromiseCallback(promise))
  }

  @ReactMethod
  fun getTransactions(
    walletId: String? = null,
    assetRef: String? = null,
    bip44: String? = null,
    tokenAddress: String? = null,
    limit: Int = 100,
    offset: Int = 0,
    promise: Promise,
  ) {
    metaOneSDKManager.apiManager.getTransactions(walletId, assetRef, bip44, tokenAddress, limit, offset, PromiseCallback(promise))
  }

  @ReactMethod
  fun getNFTs(
    walletId: String? = null,
    searchString: String? = null,
    limit: Int = 100,
    offset: Int = 0,
    promise: Promise,
  ) {
    metaOneSDKManager.apiManager.getNFTs(walletId, searchString, limit, offset, PromiseCallback(promise))
  }

  @ReactMethod
  fun getUserContacts(promise: Promise) {
    metaOneSDKManager.apiManager.getUserContacts(PromiseCallback(promise))
  }

  @ReactMethod
  fun getUserContactWithId(id: String, promise: Promise) {
    metaOneSDKManager.apiManager.getUserContactWithId(id, PromiseCallback(promise))
  }

  @ReactMethod
  fun addUserContact(data: ReadableMap, promise: Promise) {
    val request = Gson().fromJson(data.toString(), Contacts.ContactRequest::class.java)
    metaOneSDKManager.apiManager.addUserContact(request, PromiseCallback(promise))
  }

  @ReactMethod
  fun updateUserContact(id: String, data: ReadableMap, promise: Promise) {
    val request = Gson().fromJson(data.toString(), Contacts.ContactRequest::class.java)
    metaOneSDKManager.apiManager.updateUserContact(id, request, PromiseCallback(promise))
  }

  @ReactMethod
  fun deleteUserContact(id: String, promise: Promise) {
    metaOneSDKManager.apiManager.deleteUserContact(id, PromiseCallback(promise))
  }

  @ReactMethod
  fun logout() {
    metaOneSDKManager.logout()
  }

  @ReactMethod
  fun getExpireAt(promise: Promise) {
    promise.resolve(metaOneSDKManager.getExpireAt()?.toString() ?: "")
  }
  companion object {
    const val NAME = "MetaoneWalletReactNativeSdk"
  }
}
