import type { Transactions } from "./transactions";
import type { Wallets } from "./wallets";
export interface SDKConfig {
    sdkRealm: string;
    sdkEnvironment: string;
    sdkKey: string;
    sdkConfigUrl: string;
    sdkApiClientReference: string;
    sdkApiKeyPhrase: string;
    version: string;
    mainnet: boolean;
}
export interface Paging {
    limit: number;
    offset: number;
}
export interface Response {
    responseCode: "ok" | "err.internal";
    errorType?: string;
    error?: string;
}
export declare namespace AuthApiModel {
    interface AuthResponse {
        accessToken: string;
        expireAt: number;
        idToken: string;
        refreshToken: string;
    }
    enum SessionActivityStatus {
        ACTIVE = "ACTIVE",
        UNAUTHORISED = "UNAUTHORISED",
        EXPIRED = "EXPIRED"
    }
}
export declare namespace WalletsAPIModel {
    interface UserWalletsResponse {
        wallets: Wallets.UserWallet[];
    }
    interface UserWalletResponse {
        wallet: Wallets.UserWallet;
    }
    interface UserCurrenciesResponse {
        currencies: Wallets.UserCurrency[];
    }
    interface UserCurrencyResponse {
        currency: Wallets.UserCurrency;
    }
    interface UserNFTsResponse {
        data: {
            entries: Wallets.UserNFT;
            total: number;
        };
    }
}
export declare namespace TransactionAPIModel {
    interface TransactionsResponse extends Response {
        data: {
            entries: Array<Transactions.UserTransaction>;
            total: number;
            page?: number;
        };
    }
}
export declare namespace ContactsApiModel {
    interface ContactWalletAddress {
        id: string;
        name: string;
        address: string;
    }
    interface Contact {
        id?: string;
        name: string;
        photo?: string;
        wallets: ContactWalletAddress[];
    }
    interface ContactsResponse extends Response {
        data: {
            contacts: Contact[];
        };
    }
    interface ContactRequest {
        data: Contact;
    }
    interface ContactResponse extends Response {
        data: Contact;
    }
}
export declare enum LanguageType {
    "ENGLISH" = "en-US",
    "VIETNAMESE" = "vi-VN",
    "INDONESIAN" = "in-ID",
    "FILIPINO" = "tl-PH",
    "CHINESE_SIMPLIFIED" = "zh-CN",
    "CHINESE_TRADITIONAL" = "zh-TW"
}
export interface ColorsScheme {
    alwaysWhite?: string;
    alwaysBlack?: string;
    primary?: string;
    primary80?: string;
    primary60?: string;
    primary40?: string;
    primary20?: string;
    secondary?: string;
    secondary80?: string;
    secondary60?: string;
    secondary40?: string;
    secondary20?: string;
    primaryButtonBg?: string;
    primaryButtonBgDisabled?: string;
    primaryButtonText?: string;
    secondaryButtonBg?: string;
    secondaryButtonBgDisabled?: string;
    secondaryButtonText?: string;
    errorButtonBg?: string;
    errorButtonText?: string;
    green?: string;
    greenBg?: string;
    yellow?: string;
    yellowBg?: string;
    yellow15?: string;
    red?: string;
    redBg?: string;
    blue?: string;
    blueBg?: string;
    wireframes?: string;
    wireframesLight?: string;
    gradientLight?: string;
    gradientViolet?: string;
    gradientBlue?: string;
    average?: string;
    background?: string;
    background20?: string;
    white?: string;
    white20?: string;
    white50?: string;
    white80?: string;
    black?: string;
    black80?: string;
    black60?: string;
    black40?: string;
    black20?: string;
    black15?: string;
    black5?: string;
    black10?: string;
}
export declare namespace UserDataModel {
    interface UserData {
        user: string;
        name: string;
        email: string;
        avatar?: string | null;
        update?: number | null;
    }
    interface ProfileData {
        profile: UserData;
        ackTnC?: boolean;
        ackPrivacy?: boolean;
        hasPwd?: boolean;
        referralCode?: string;
        referencedBy?: string;
    }
    interface UserState {
        setPin: boolean;
        setSecurityQuestions: boolean;
    }
}
//# sourceMappingURL=index.d.ts.map