import { NativeModules, Platform } from 'react-native';
import type {
  AuthApiModel,
  ColorsScheme,
  ContactsApiModel,
  LanguageType,
  Response,
  SDKConfig,
  WalletsAPIModel,
} from './types';

const LINKING_ERROR =
  `The package '@aag-development/react-native-metaone-wallet-sdk' doesn't seem to be linked. Make sure: \n\n` +
  Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
  '- You rebuilt the app after installing the package\n' +
  '- You are not using Expo Go\n';

const MetaoneWalletReactNativeSdk = NativeModules.MetaoneWalletReactNativeSdk
  ? NativeModules.MetaoneWalletReactNativeSdk
  : new Proxy(
      {},
      {
        get() {
          throw new Error(LINKING_ERROR);
        },
      }
    );

export function initialize(config: SDKConfig): Promise<boolean> {
  return MetaoneWalletReactNativeSdk.initialize(config);
}

export function loginWithSSO(token: string): Promise<boolean> {
  return MetaoneWalletReactNativeSdk.loginWithSSO(token);
}

export function refreshSession(): Promise<boolean> {
  return MetaoneWalletReactNativeSdk.refreshSession();
}

export function openWallet(): void {
  MetaoneWalletReactNativeSdk.openWallet();
}

export function getSessionActivityStatus(): Promise<AuthApiModel.SessionActivityStatus> {
  return MetaoneWalletReactNativeSdk.getSessionActivityStatus();
}

export function getColorsScheme(): Promise<ColorsScheme> {
  return MetaoneWalletReactNativeSdk.getColorsScheme();
}

export function setColorsScheme(colors: ColorsScheme): void {
  MetaoneWalletReactNativeSdk.setColorsScheme(colors);
}

export function getCurrentLanguage(): Promise<LanguageType> {
  return MetaoneWalletReactNativeSdk.getCurrentLanguage();
}

export function setCurrentLanguage(language: LanguageType): void {
  MetaoneWalletReactNativeSdk.setCurrentLanguage(language);
}

export function getWallets(): Promise<WalletsAPIModel.UserWalletsResponse> {
  return MetaoneWalletReactNativeSdk.getWallets();
}

export function getCurrencies(): Promise<WalletsAPIModel.UserCurrenciesResponse> {
  return MetaoneWalletReactNativeSdk.getCurrencies();
}

export function getTransactions(
  walletId?: string,
  assetRef?: string,
  bip44?: string,
  tokenAddress?: string,
  limit?: number,
  offset?: number
): Promise<LanguageType> {
  return MetaoneWalletReactNativeSdk.getTransactions(
    walletId,
    assetRef,
    bip44,
    tokenAddress,
    String(limit ? limit : 100),
    String(offset ? offset : 0)
  );
}

export function getNFTs(
  walletId?: string,
  searchString?: string,
  limit?: number,
  offset?: number
): Promise<WalletsAPIModel.UserNFTsResponse> {
  return MetaoneWalletReactNativeSdk.getNFTs(
    walletId,
    searchString,
    String(limit ? limit : 100),
    String(offset ? offset : 0)
  );
}

export function getUserContacts(): Promise<ContactsApiModel.ContactsResponse> {
  return MetaoneWalletReactNativeSdk.getUserContacts();
}

export function getUserContactWithId(
  id: string
): Promise<ContactsApiModel.ContactResponse> {
  return MetaoneWalletReactNativeSdk.getUserContactWithId(id);
}

export function addUserContact(
  contact: ContactsApiModel.Contact
): Promise<ContactsApiModel.ContactResponse> {
  return MetaoneWalletReactNativeSdk.addUserContact(contact);
}

export function updateUserContact(
  id: string,
  contact: ContactsApiModel.Contact
): Promise<ContactsApiModel.ContactResponse> {
  return MetaoneWalletReactNativeSdk.updateUserContact(id, contact);
}

export function deleteUserContact(contactId: string): Promise<Response> {
  return MetaoneWalletReactNativeSdk.deleteUserContact(contactId);
}

export function logout(): void {
  MetaoneWalletReactNativeSdk.logout();
}

export function getExpireAt(): Promise<string> {
  return MetaoneWalletReactNativeSdk.getExpireAt();
}

export * from './types';
