import type { Transactions } from "./transactions";
import type { Wallets } from "./wallets";

export interface SDKConfig {
    sdkRealm: string,
    sdkEnvironment: string,
    sdkKey: string,
    sdkConfigUrl: string,
    sdkApiClientReference: string,
    sdkApiKeyPhrase: string,
    version: string,
    mainnet: boolean
}

export interface Paging {
    limit: number;
    offset: number;
}

export interface Response {
    responseCode: "ok" | "err.internal";
    errorType?: string;
    error?: string;
}

export namespace AuthApiModel {
    export interface AuthResponse {
        accessToken: string;
        expireAt: number;
        idToken: string;
        refreshToken: string;
    }

    export enum SessionActivityStatus {
        ACTIVE = 'ACTIVE',
        UNAUTHORISED = 'UNAUTHORISED',
        EXPIRED = 'EXPIRED',
    }
}

export namespace WalletsAPIModel {
    export interface UserWalletsResponse {
        wallets: Wallets.UserWallet[]
    }

    export interface UserWalletResponse {
        wallet: Wallets.UserWallet
    }

    export interface UserCurrenciesResponse {
        currencies: Wallets.UserCurrency[]
    }

    export interface UserCurrencyResponse {
        currency: Wallets.UserCurrency
    }

    export interface UserNFTsResponse {
        data: {
            entries: Wallets.UserNFT,
            total: number
        }
    }
}

export namespace TransactionAPIModel {
    export interface TransactionsResponse extends Response {
        data : {
            entries: Array<Transactions.UserTransaction>;
            total: number;
            page?: number;
        }
    }
}

export namespace ContactsApiModel {
    export interface ContactWalletAddress {
        id: string;
        name: string;
        address: string;
    }

    export interface Contact {
        id?: string;
        name: string;
        photo?: string;
        wallets: ContactWalletAddress[]
    }
    export interface ContactsResponse extends Response {
        data: {
            contacts: Contact[]
        }
    }

    export interface ContactRequest {
        data: Contact
    }
    export interface ContactResponse extends Response {
        data: Contact
    }
}

export enum LanguageType {
    "ENGLISH" = "en-US",
    "VIETNAMESE" = "vi-VN",
    "INDONESIAN" = "in-ID",
    "FILIPINO" = "tl-PH",
    "CHINESE_SIMPLIFIED" = "zh-CN",
    "CHINESE_TRADITIONAL" = "zh-TW",
}

export interface ColorsScheme {
    alwaysWhite?: string;
    alwaysBlack?: string;
    primary?: string;
    primary80?: string;
    primary60?: string;
    primary40?: string;
    primary20?: string;
    secondary?: string;
    secondary80?: string;
    secondary60?: string;
    secondary40?: string;
    secondary20?: string;
    primaryButtonBg?: string;
    primaryButtonBgDisabled?: string;
    primaryButtonText?: string;
    secondaryButtonBg?: string;
    secondaryButtonBgDisabled?: string;
    secondaryButtonText?: string;
    errorButtonBg?: string;
    errorButtonText?: string;
    green?: string;
    greenBg?: string;
    yellow?: string;
    yellowBg?: string;
    yellow15?: string;
    red?: string;
    redBg?: string;
    blue?: string;
    blueBg?: string;
    wireframes?: string;
    wireframesLight?: string;
    gradientLight?: string;
    gradientViolet?: string;
    gradientBlue?: string;
    average?: string;
    background?: string;
    background20?: string;
    white?: string;
    white20?: string;
    white50?: string;
    white80?: string;
    black?: string;
    black80?: string;
    black60?: string;
    black40?: string;
    black20?: string;
    black15?: string;
    black5?: string;
    black10?: string;
}
export namespace UserDataModel {
    export interface UserData {
        user: string;
        name: string;
        email: string;
        avatar?: string | null;
        update?: number | null;
    }

    export interface ProfileData {
        profile: UserData;
        ackTnC?: boolean;
        ackPrivacy?: boolean;
        hasPwd?: boolean;
        referralCode?: string;
        referencedBy?: string;
    }

    export interface UserState {
        setPin: boolean;
        setSecurityQuestions: boolean;
        // enableBiometrics: boolean;
        // smsVerified: boolean;
        // skipSmsVerify: boolean;
        // accountSkipSmsVerify: boolean;
        // enableWalletconnect: boolean;

        // realName: string;
        // email: string;
        // language: string;
        // countryCode: string;
        // phone: string;
        // userReferralCode: string;
        // linkUserReferralCode: string;
        // liquidKey: string;
    }
}
